+
+
- <%: traduci("NumTrattamento") %>
+ <%: traduci("TrattNoProveMecc") %>
-
-
-
- <%: traduci("Durezza") %>(AL)
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/GMW/WebUserControls/mod_PostProveMecc.ascx.designer.cs b/GMW/WebUserControls/mod_PostProveMecc.ascx.designer.cs
index b33fa926..8a432017 100644
--- a/GMW/WebUserControls/mod_PostProveMecc.ascx.designer.cs
+++ b/GMW/WebUserControls/mod_PostProveMecc.ascx.designer.cs
@@ -13,31 +13,31 @@ namespace GMW.WebUserControls {
public partial class mod_PostProveMecc {
///
- /// lblAL control.
+ /// lblNtDelib control.
///
///
/// Auto-generated field.
/// To modify move field declaration from designer file to code-behind file.
///
- protected global::System.Web.UI.WebControls.Label lblAL;
+ protected global::System.Web.UI.WebControls.Label lblNtDelib;
///
- /// grViewSource control.
+ /// grViewDPM control.
///
///
/// Auto-generated field.
/// To modify move field declaration from designer file to code-behind file.
///
- protected global::System.Web.UI.WebControls.GridView grViewSource;
+ protected global::System.Web.UI.WebControls.GridView grViewDPM;
///
- /// odsSource control.
+ /// odsDPM control.
///
///
/// Auto-generated field.
/// To modify move field declaration from designer file to code-behind file.
///
- protected global::System.Web.UI.WebControls.ObjectDataSource odsSource;
+ protected global::System.Web.UI.WebControls.ObjectDataSource odsDPM;
///
/// divBarcode control.
@@ -67,75 +67,66 @@ namespace GMW.WebUserControls {
protected global::System.Web.UI.WebControls.TextBox txtBarcode;
///
- /// divNote control.
+ /// divEsitoPM control.
///
///
/// Auto-generated field.
/// To modify move field declaration from designer file to code-behind file.
///
- protected global::System.Web.UI.HtmlControls.HtmlGenericControl divNote;
+ protected global::System.Web.UI.HtmlControls.HtmlGenericControl divEsitoPM;
///
- /// txtNote control.
+ /// txtEsitoPM control.
///
///
/// Auto-generated field.
/// To modify move field declaration from designer file to code-behind file.
///
- protected global::System.Web.UI.WebControls.TextBox txtNote;
+ protected global::System.Web.UI.WebControls.TextBox txtEsitoPM;
///
- /// divStampa control.
+ /// divDelibera control.
///
///
/// Auto-generated field.
/// To modify move field declaration from designer file to code-behind file.
///
- protected global::System.Web.UI.HtmlControls.HtmlGenericControl divStampa;
+ protected global::System.Web.UI.HtmlControls.HtmlGenericControl divDelibera;
///
- /// lbtStampaAL control.
+ /// lbtDeliberaTT control.
///
///
/// Auto-generated field.
/// To modify move field declaration from designer file to code-behind file.
///
- protected global::System.Web.UI.WebControls.LinkButton lbtStampaAL;
+ protected global::System.Web.UI.WebControls.LinkButton lbtDeliberaTT;
///
- /// divNumTratt control.
+ /// lblNtNoDelib control.
///
///
/// Auto-generated field.
/// To modify move field declaration from designer file to code-behind file.
///
- protected global::System.Web.UI.HtmlControls.HtmlGenericControl divNumTratt;
+ protected global::System.Web.UI.WebControls.Label lblNtNoDelib;
///
- /// txtNumTratt control.
+ /// grViewTT control.
///
///
/// Auto-generated field.
/// To modify move field declaration from designer file to code-behind file.
///
- protected global::System.Web.UI.WebControls.TextBox txtNumTratt;
+ protected global::System.Web.UI.WebControls.GridView grViewTT;
///
- /// divDurezza control.
+ /// odsTratt control.
///
///
/// Auto-generated field.
/// To modify move field declaration from designer file to code-behind file.
///
- protected global::System.Web.UI.HtmlControls.HtmlGenericControl divDurezza;
-
- ///
- /// txtDurezza control.
- ///
- ///
- /// Auto-generated field.
- /// To modify move field declaration from designer file to code-behind file.
- ///
- protected global::System.Web.UI.WebControls.TextBox txtDurezza;
+ protected global::System.Web.UI.WebControls.ObjectDataSource odsTratt;
}
}
diff --git a/GMW/WebUserControls/mod_selLineaNtDt.ascx.cs b/GMW/WebUserControls/mod_selLineaNtDt.ascx.cs
index 5bfaa3c5..b383c60e 100644
--- a/GMW/WebUserControls/mod_selLineaNtDt.ascx.cs
+++ b/GMW/WebUserControls/mod_selLineaNtDt.ascx.cs
@@ -394,5 +394,19 @@ namespace GMW.WebUserControls
lbtNT.Visible = value;
}
}
+ ///
+ /// determina visibilità btn storico
+ ///
+ public bool showStorico
+ {
+ get
+ {
+ return lbtShowHideStorico.Visible;
+ }
+ set
+ {
+ lbtShowHideStorico.Visible = value;
+ }
+ }
}
}
\ No newline at end of file
diff --git a/GMW/WebUserControls/mod_PostProveMecc.ascx.cs b/GMW/WebUserControls/mod_PostProveMecc.ascx.cs
index 2d992a09..c3365c11 100644
--- a/GMW/WebUserControls/mod_PostProveMecc.ascx.cs
+++ b/GMW/WebUserControls/mod_PostProveMecc.ascx.cs
@@ -16,57 +16,49 @@ namespace GMW.WebUserControls
///
public event EventHandler eh_reqUpdate;
///
- /// flusso associato (hard coded) a RX
+ /// Codice attributo da salvare x Prove Meccaniche
///
- protected string flusso = "TT";
+ protected string CodAttr = "PM";
///
- /// stato associato (hard coded) a Controllato RX
+ /// Numero Trattamento (già deliberato)
///
- protected string statoUDC = "Tratt";
- ///
- /// codice evento dell'UDC che si crea
- ///
- protected string codEventoUdc = "UDC_TRATT";
- ///
- /// Codice AL sorgente da avanzare RX --> TT
- ///
- protected string sourceAL
+ protected string NumTT_Delib
{
get
{
- return lblAL.Text.Trim();
+ return lblNtDelib.Text.Trim();
}
set
{
- lblAL.Text = value;
+ lblNtDelib.Text = value;
}
}
///
- /// Numero trattamento
+ /// Numero Trattamento (NON ANCORA deliberato)
///
- protected string NumTratt
+ protected string NumTT_NoDelib
{
get
{
- return txtNumTratt.Text.Trim();
+ return lblNtNoDelib.Text.Trim();
}
set
{
- txtNumTratt.Text = value;
+ lblNtNoDelib.Text = value;
}
}
///
- /// Durezza
+ /// EsitoPM
///
- public string Durezza
+ public string EsitoPM
{
get
{
- return txtDurezza.Text.Trim();
+ return txtEsitoPM.Text.Trim();
}
set
{
- txtDurezza.Text = value;
+ txtEsitoPM.Text = value;
}
}
///
@@ -83,14 +75,13 @@ namespace GMW.WebUserControls
checkBarcode();
}
///
- /// restta input
+ /// resetta input
///
private void resetIN()
{
- sourceAL = "";
- NumTratt = "";
- Durezza = "";
- txtNote.Text = "";
+ NumTT_Delib = "";
+ NumTT_Delib = "";
+ EsitoPM = "";
}
///
/// wrapper traduzione
@@ -120,6 +111,23 @@ namespace GMW.WebUserControls
///
private void checkBarcode()
{
+ /**********************************
+ * check barcode deve funzioanre così:
+ * - accetta reset
+ * - cerca in TUTTI i trattamenti se sia valido codice BCode / manuale (fare che select laterale seleziona stesso valore)
+ * - se è in DPM (già deliberato) filtro li (e nascondo tutto su TT da deliberare)
+ * - se è TT non deliberati al contrario mostro li e non in DPM (sempre con filtro su ods)
+ * - mostro txt x inserire valore della PM
+ * - mostro button deliberare
+ * - post delibera aggiorno (togliendo filtri e selezioni valori)
+ *
+ * nb:
+ * - delibere in ordine cronologico DESC
+ * - trattamenti FIFO (ASC)
+ *
+ * */
+
+#if false
if (barcodeIn != "")
{
Postazione.messaggiText = string.Format("{0}: {1}", traduci("BCodeIns"), barcodeIn);
@@ -182,9 +190,11 @@ namespace GMW.WebUserControls
{
Postazione.messaggiText = traduci("AttesaBCode");
Postazione.CssClass = "stileAttesa";
- }
+ }
+#endif
doUpdate();
}
+#if false
///
/// Verifica l'AL se sia ok x procedere:
/// - Tipo "R"
@@ -238,20 +248,23 @@ namespace GMW.WebUserControls
Postazione.warningText = "";
}
return answ;
- }
+ }
+#endif
///
/// aggiorna componenti + focus a barcode
///
public void doUpdate()
{
- grViewSource.DataBind();
+ grViewDPM.DataBind();
+ grViewTT.DataBind();
updateBtns();
// raise dell'evento
if (eh_reqUpdate != null)
{
eh_reqUpdate(this, new EventArgs());
}
// controllo SE ho AL allora seleziono NumTratt o Durezza...
if (sourceAL == "")
{
txtBarcode.Focus();
@@ -264,80 +277,51 @@ namespace GMW.WebUserControls
}
else
{
- if (Durezza == "")
+ if (EsitoPM == "")
{
- txtDurezza.Focus();
+ txtEsitoPM.Focus();
}
else
{
- if (txtNote.Text.Trim() == "")
- {
- txtNote.Focus();
- }
- else
- {
- lbtStampaAL.Focus();
- }
+ lbtDeliberaTT.Focus();
}
}
- }
+ }
+#endif
}
///
/// fix visibilità btnStampa
///
private void updateBtns()
{
- // posso stampare se ho AL, ho num tratt e durezza..
- bool btnVis = (sourceAL != "");
- divNumTratt.Visible = btnVis;
- divDurezza.Visible = btnVis;
- // posso stampare se ho AL, ho num tratt e durezza..
- btnVis = (sourceAL != "" && NumTratt != "" && Durezza != "");
- divStampa.Visible = btnVis;
+ // posso vedere esito PM se ho un numero tratt
+ bool btnVis = (NumTT_Delib != "" || NumTT_NoDelib!="");
+ divEsitoPM.Visible = btnVis;
+ // posso stampare se ho numero tratt ed EsitoPM..
+ btnVis = (NumTT_Delib != "" || NumTT_NoDelib != "" && EsitoPM != "");
+ divDelibera.Visible = btnVis;
}
///
- /// richiesta (ri)stampa UDC
+ /// salva/aggiorna delibera di un TT
///
///
///
- public void ristampa()
- {
- MagClass.magazzino.stampaAL(udcReq, Postazione.printer, tipoCartellino.cartAL, Request.UserHostName);
- // registro ri-stampa UDC
- MagClass.magazzino.taSAO.insertQuery(DateTime.Now, MagClass.magazzino.CodSoggCurrUser, Postazione.name, Postazione.IP, udcReq, "", "stampaAL", "Ri-Stampato AL TT");
- Postazione.CssClass = "stileAttesa";
- }
- ///
- /// udc da stampare
- ///
- protected string udcReq
- {
- get
- {
- return memLayer.ML.StringSessionObj("udcSelSAO");
- }
- }
- ///
- /// (ri)stampa AL
- ///
- ///
- ///
- protected void lbtStampaAL_Click(object sender, EventArgs e)
+ protected void lbtDeliberaTT_Click(object sender, EventArgs e)
{
+#if false
/* generazione e stampa AL */
string AL = "";
- string noteTrim = txtNote.Text.Trim();
// creazione AL ed associazione UDC / spostamento...
try
{
- AL = MagClass.magazzino.creaAssociaAlTT(sourceAL, tipoAL.AL_TT, MagClass.magazzino.CodSoggCurrUser, noteTrim, NumTratt, Durezza);
+ AL = MagClass.magazzino.creaAssociaAlTT(sourceAL, tipoAL.AL_TT, MagClass.magazzino.CodSoggCurrUser, noteTrim, NumTratt, EsitoPM);
}
catch
{ }
if (AL != "")
{
// lancio stampa
- MagClass.magazzino.stampaAL(AL, Postazione.printer, tipoCartellino.cartAL, Request.UserHostName);
+ MagClass.magazzino.DeliberaTT(AL, Postazione.printer, tipoCartellino.cartAL, Request.UserHostName);
// registro creazione AL
MagClass.magazzino.taSAO.insertQuery(DateTime.Now, MagClass.magazzino.CodSoggCurrUser, Postazione.name, Postazione.IP, AL, "", "creaAL", string.Format("Creato AL TT su linea {0}, note: {1} ", Postazione.currCodLinea, noteTrim));
Postazione.CssClass = "stileAttesa";
@@ -351,7 +335,8 @@ namespace GMW.WebUserControls
Postazione.CssClass = "stileComandoKo";
Postazione.warningText = traduci("ErroreCreazioneALTT");
Postazione.messaggiText = "";
- }
+ }
+#endif
doUpdate();
}
///
@@ -364,11 +349,11 @@ namespace GMW.WebUserControls
doUpdate();
}
///
- /// inserita durezza
+ /// inserita EsitoPM
///
///
///
- protected void txtDurezza_TextChanged(object sender, EventArgs e)
+ protected void txtEsitoPM_TextChanged(object sender, EventArgs e)
{
doUpdate();
}
@@ -238,20 +248,23 @@ namespace GMW.WebUserControls
eh_reqUpdate(this, new EventArgs());
}
- // controllo SE ho AL allora seleziono NumTratt o Durezza...
+#if false
+ // controllo SE ho AL allora seleziono NumTratt o EsitoPM...
if (sourceAL == "")
{
diff --git a/GMW/bin/GMW.dll b/GMW/bin/GMW.dll
index 68d04e45..b38a3a8b 100644
Binary files a/GMW/bin/GMW.dll and b/GMW/bin/GMW.dll differ
diff --git a/GMW/bin/GMW_data.dll b/GMW/bin/GMW_data.dll
index 00bf8c13..85c0000c 100644
Binary files a/GMW/bin/GMW_data.dll and b/GMW/bin/GMW_data.dll differ
diff --git a/GMW/bin/SteamWare.dll b/GMW/bin/SteamWare.dll
index fedbc2d9..ae133cbe 100644
Binary files a/GMW/bin/SteamWare.dll and b/GMW/bin/SteamWare.dll differ